@@ -2,9 +2,9 @@
  *
  * rasqal_general.c - Rasqal library startup, shutdown and factories
  *
- * $Id: rasqal_general.c 5355 2006-01-12 05:21:19Z cmdjb $
+ * $Id: rasqal_general.c 11816 2007-01-24 07:47:50Z dajobe $
  *
- * Copyright (C) 2004-2006, David Beckett http://purl.org/net/dajobe/
+ * Copyright (C) 2004-2007, David Beckett http://purl.org/net/dajobe/
  * Copyright (C) 2004-2005, University of Bristol, UK http://www.bristol.ac.uk/
  * 
  * This package is Free Software and part of Redland http://librdf.org/
@@ -56,9 +56,13 @@ static int rasqal_finishing=0;
 /* list of query factories */
 static rasqal_query_engine_factory* query_engines=NULL;
 
-const char * const rasqal_short_copyright_string = "Copyright 2003-2006 David Beckett.  Copyright 2003-2005 University of Bristol";
+const char * const rasqal_short_copyright_string = "Copyright 2003-2007 David Beckett.  Copyright 2003-2005 University of Bristol";
 
-const char * const rasqal_copyright_string = "Copyright (C) 2003-2006 David Beckett - http://purl.org/net/dajobe/\nCopyright 2003-2005 University of Bristol - http://www.bristol.ac.uk/";
+const char * const rasqal_copyright_string = "Copyright (C) 2003-2007 David Beckett - http://purl.org/net/dajobe/\nCopyright (C) 2003-2005 University of Bristol - http://www.bristol.ac.uk/";
+
+const char * const rasqal_license_string = "LGPL 2.1 or newer, GPL 2 or newer, Apache 2.0 or newer.\nSee http://librdf.org/rasqal/LICENSE.html for full terms.";
+
+const char * const rasqal_home_url_string = "http://librdf.org/rasqal/";
 
 /**
  * rasqal_version_string:
@@ -125,6 +129,10 @@ rasqal_init(void)
   rasqal_init_query_engine_rdql();
 #endif
 
+#ifdef RASQAL_QUERY_LAQRS
+  rasqal_init_query_engine_laqrs();
+#endif
+
 #ifdef RASQAL_QUERY_SPARQL  
   rasqal_init_query_engine_sparql();
 #endif
@@ -136,6 +144,8 @@ rasqal_init(void)
   rasqal_redland_init();
 #endif
 
+  rasqal_init_query_results();
+
   rasqal_initialising=0;
   rasqal_initialised=1;
   rasqal_finishing=0;
@@ -156,6 +166,8 @@ rasqal_finish(void)
     return;
   rasqal_finishing=1;
 
+  rasqal_finish_query_results();
+
   rasqal_delete_query_engine_factories();
 
 #ifdef RAPTOR_TRIPLES_SOURCE_REDLAND
@@ -349,7 +361,7 @@ rasqal_languages_enumerate(const unsigned int counter,
   unsigned int i;
   rasqal_query_engine_factory *factory=query_engines;
 
-  if(!factory || counter < 0)
+  if(!factory)
     return 1;
 
   for(i=0; factory && i<=counter ; i++, factory=factory->next) {
@@ -591,7 +603,7 @@ rasqal_escaped_name_to_utf8_string(const unsigned char *src, size_t len,
     if(c > 0x7f) {
       /* just copy the UTF-8 bytes through */
       size_t unichar_len=raptor_utf8_to_unicode_char(NULL, (const unsigned char*)p, len+1);
-      if(unichar_len < 0 || unichar_len > len) {
+      if(unichar_len > len) {
         if(error_handler)
           error_handler(error_data, "UTF-8 encoding error at character %d (0x%02X) found.", c, c);
         /* UTF-8 encoding had an error or ended in the middle of a string */
@@ -646,7 +658,7 @@ rasqal_escaped_name_to_utf8_string(const unsigned char *src, size_t len,
         p+=ulen;
         len-=ulen;
         
-        if(unichar < 0 || unichar > 0x10ffff) {
+        if(unichar > 0x10ffff) {
           if(error_handler)
             error_handler(error_data, "Illegal Unicode character with code point #x%lX.", unichar);
           break;
@@ -693,7 +705,7 @@ raptor_uri* rasqal_rdf_nil_uri=NULL;
 
 
 void
-rasqal_uri_init() 
+rasqal_uri_init(void) 
 {
   rasqal_xsd_namespace_uri=raptor_new_uri(raptor_xmlschema_datatypes_namespace_uri);
   
@@ -715,7 +727,7 @@ rasqal_uri_init()
 
 
 void
-rasqal_uri_finish() 
+rasqal_uri_finish(void) 
 {
   if(rasqal_xsd_integer_uri)
     raptor_free_uri(rasqal_xsd_integer_uri);
